# Teals Homework Library

For TEALS homework because asgh all weve done so far has been review why ahhhhh

# Quickstart:
```
shell -> pip install tealshwlibrary

from tealshwlibrary.June7 import June7
print(June7.factorial(7))
```

# Documentation:

### June7
| function        | description           
| ----------: |:-:| 
| `is_prime(integer)`      | if integer is a prime, return True, else returns False | 
| `factorial(integer)`     | returns factorial of integer
      |   
| `integer_input()` | continuously asks user for an integer input, returns the integer     |  

### June8
| function | description
| -: | :-: |
| `happy_birthday(name)`| requires a name parameter, prints happy birthday song
| `pick_cards(integer, *argv)` | given an integer and any number of lists, returns [integer] amount of random choices from every list
